regmedint-package: regmedint: A package for regression-based causal mediation...

regmedint-packageR Documentation

regmedint: A package for regression-based causal mediation analysis

Description

The package is an R implementation of regression-based closed-form causal mediation as originally described in Valeri & VanderWeele 2013 and Valeri & VanderWeele 2015 https://hsph.harvard.edu/research/vanderweele-group/tools-and-tutorials/. The earlier version is a sister program of the SAS macro. The current extended version (version 1.0 and later) supports effect modification by covariates (treatment-covariate and mediator-covariate product terms) in mediator and outcome models.

Fitting models

Use the regmedint function to fit models and set up regression-based causal mediation analysis.

Examining results

Several methods are available to examine the regmedint object. print summary coef confint

Author(s)

Maintainer: Yi Li yi.li10@mail.mcgill.ca (ORCID)

Authors:

Other contributors:

  • Maya Mathur (ORCID) [contributor]

See Also

Useful links:


regmedint documentation built on March 6, 2026, 9:09 a.m.