| regmedint-package | R Documentation |
The package is an R implementation of regression-based closed-form causal mediation as originally described in Valeri & VanderWeele 2013 and Valeri & VanderWeele 2015 https://hsph.harvard.edu/research/vanderweele-group/tools-and-tutorials/. The earlier version is a sister program of the SAS macro. The current extended version (version 1.0 and later) supports effect modification by covariates (treatment-covariate and mediator-covariate product terms) in mediator and outcome models.
Use the regmedint function to fit models and set up regression-based causal mediation analysis.
Several methods are available to examine the regmedint object. print summary coef confint
Maintainer: Yi Li yi.li10@mail.mcgill.ca (ORCID)
Authors:
Kazuki Yoshida kazukiyoshida@mail.harvard.edu (ORCID) [contributor]
Other contributors:
Maya Mathur (ORCID) [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.